<?php
/**
 * MIT License
 *
 * Copyright (c) 2017 CM Groep
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in all
 * copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 *
 * @category   CMGroep
 * @package    Idin
 * @author     Epartment Ecommerce B.V. <support@epartment.nl>
 * @copyright  2016-2017 CM Groep
 * @license    http://www.opensource.org/licenses/mit-license.html  MIT License
 */

class CMGroep_Idin_Block_Checkout_Onepage_Js extends Mage_Core_Block_Template
{
    /**
     * Only render when age verification is active
     *
     * @return string
     */
    public function _toHtml()
    {
        if (Mage::helper('cmgroep_idin')->getIdinAgeVerificationActive()
            && Mage::helper('cmgroep_idin')->ageVerificationRequired(true) && Mage::helper('cmgroep_idin')->getExtensionActive()) {
            return parent::_toHtml();
        }
    }

    /**
     * Get checkout method after age verification in order to
     * skip the authentication step in OnePageCheckout
     *
     * @return string
     */
    public function getCheckoutMethod()
    {
        return Mage::getSingleton('core/session')->getData('idin_checkout_method');
    }

    /**
     * Get active step
     *
     * @return string
     */
    public function getActiveStep()
    {
        if (Mage::helper('customer')->isLoggedIn() == false) {
            return 'login';
        } else {
            if (Mage::helper('cmgroep_idin')->ageVerificationRequired()) {
                return 'age_verification';
            } else {
                return 'billing';
            }
        }
    }
}